#[repr(u32)]pub enum EngineInput {
Show 23 variants
None = 0,
DPAD_LEFT = 1,
DPAD_RIGHT = 2,
DPAD_DOWN = 4,
DPAD_UP = 8,
Z = 16,
R = 32,
L = 64,
A = 256,
B = 512,
X = 1_024,
Y = 2_048,
START = 4_096,
JOYSTICK_UP = 65_536,
JOYSTICK_DOWN = 131_072,
JOYSTICK_LEFT = 262_144,
JOYSTICK_RIGHT = 524_288,
CSTICK_UP = 1_048_576,
CSTICK_DOWN = 2_097_152,
CSTICK_LEFT = 4_194_304,
CSTICK_RIGHT = 8_388_608,
ANY_TRIGGER = 2_147_483_648,
Raw(u32),
}Expand description
The buttons as interpreted by the game engine. See buttons::Controller for buttons as seen by
the console’s controller polls directly.
Can be casted trivially to and from u32 via deref abuse
let flags = EngineInput::X | EngineInput::A | EngineInput::L;
let val: u32 = *flags;
let back: EngineInput = val.into();
let back_again = EngineInput::from(val);Notably, the engine considers Z presses to be analog trigger 0.35 + Z + A, while the controller sees Z as just Z.
ANY_TRIGGER is active when either L or R is active, and/or when there is an analog value
= 0.30
Variants
None = 0
DPAD_LEFT = 1
DPAD_RIGHT = 2
DPAD_DOWN = 4
DPAD_UP = 8
Z = 16
When active, will always also be accompanied by A and ANY_TRIGGER
If you’re looking for Z in isolation, use buttons::Controller
R = 32
Digital press
L = 64
Digital press
A = 256
B = 512
X = 1_024
Y = 2_048
START = 4_096
JOYSTICK_UP = 65_536
JOYSTICK_DOWN = 131_072
JOYSTICK_LEFT = 262_144
JOYSTICK_RIGHT = 524_288
CSTICK_UP = 1_048_576
CSTICK_DOWN = 2_097_152
CSTICK_LEFT = 4_194_304
CSTICK_RIGHT = 8_388_608
ANY_TRIGGER = 2_147_483_648
active when either L or R is active, and/or when there is an analog value
= 0.30
Raw(u32)